(function (document) {
  const markers = [...document.querySelectorAll('mark')];

  const observer = new IntersectionObserver(entries => {
    entries.forEach((entry) => {
      if (entry.intersectionRatio > 0) {
        entry.target.style.animationPlayState = 'running';
        observer.unobserve(entry.target);
      }
    });
  }, {
    threshold: 1,
    rootMargin: "0px 0px -10% 0px",
  });

  markers.forEach(mark => {
    observer.observe(mark);
  });
})(document);

const isInViewport = function (elem) {
  const bounding = elem.getBoundingClientRect();
  return (
      bounding.top >= 0 &&
      bounding.left >= 0 &&
      bounding.bottom <= (window.innerHeight || document.documentElement.clientHeight) &&
      bounding.right <= (window.innerWidth || document.documentElement.clientWidth)
  );
};

function getRandom(min, max) {
  return Math.floor(Math.random() * (max - min + 1)) + min;
}

function countDown(elem){
  let num = parseInt(elem.textContent);
  if(num > 6) {
    let speed = getRandom(5,30);
    const timerId = setTimeout(function(){
      elem.textContent = num - 1;
      clearTimeout(timerId);
      countDown(elem);
    }, speed*1000);
  } else {
    elem.parentNode.classList.add('prod-left__pad--low');
  }
}

document.addEventListener('DOMContentLoaded', () => {
  const prod = document.querySelector('.js-prod-left b');
  let flagProd = 0;

  window.addEventListener('scroll', () => {
    if(isInViewport(prod) && !flagProd) {
      flagProd = 1;
      countDown(prod);
    }
  });

  window.addEventListener('scroll', stickyHeader);
  stickyHeader();
  function stickyHeader() {
    const bodySelector = document.body;

    if (window.scrollY >= 90) {
      bodySelector.classList.add('fixed-nav');
    } else {
      bodySelector.classList.remove('fixed-nav');
    }
  }

  // const commentSwiper = new Swiper('.comments-swiper', {
  //   navigation: {
  //     nextEl: '.swiper-button-next',
  //     prevEl: '.swiper-button-prev',
  //   },
  //   pagination: {
  //     el: '.swiper-pagination',
  //     type: 'bullets',
  //     dynamicBullets: true,
  //   },
  //   spaceBetween: 55,
  //   autoHeight: true,
  //   loop: true,
  // });
});